==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/lib/include/musashi/mssBase.h <==
/**
 * # CHAPTER #
 * ============================================================================
 * MUSASHIѤŪʴؿѤΥإåե
 * ============================================================================
 */

#include <musashi/mssConfig.h>

#include <stdlib.h>
#include <time.h>

#ifndef __MSSBASE_H
#define __MSSBASE_H 1


/**
 * # DEFINE #
 * ｪλ
 */
#define mssExitSuccess EXIT_SUCCESS /*ｪλ*/

/**
 * # DEFINE #
 *ǥեȤΥ顼λֹ
 */
#define mssErrorNoDefault 1

/**
 * # DEFINE #
 * 
 */
#define mssRandMax 2147483647

/**
 * # STRUCT #
 * ޥɥإפη
 */
struct mssComHelp {
  char *name;      /*ޥ̾*/
  char *version;   /*С*/
  char *title;     /*ȥ*/
  char *summary;   /**/
  char *example;   /**/
  char *reference; /*ȥޥ*/
  char *author;    /**/
  char *bugReport; /*ХݡE-mail*/
  char *homepage;  /*ޥɤ˴ؤHP*/
};

/**
 * # STRUCT #
 * MUSASHIѤ륰Хѿ¤(base.cˤ)
 */
struct mssGlobalVariables {
  struct mssComHelp *comHelp; /*ޥɥإ*/
  int    inCnt;    /*ǡϹԿ*/
  int    outCnt;   /*ǡϹԿ*/
  int    keyNo;    /*߽Υֹ*/
  int    keyCnt;   /*߽ΥιԿ*/
  int    keyLine;  /*߽ΥΤʤǤιֹ*/
                   /*嵭γƼϡAPIǤϰڹʤΤǡƥޥɤ
                     ץꤹ롣
                     inCnt,outCntϡޥɽλå(mssShowEndMsgؿ)
                     ΰȤƽϤ롣*/
  int    inFldCnt; /*ϥǡιܿ(cal_priorؿ)*/
  int    quiet;    /*åϤ򤷤ʤե饰(mssInit,setOptionؿ)*/
  int    argc;     /*ޥɥ饤(mssInitؿ)*/
  char **argv;     /*ޥɥ饤(mssInitؿ)*/
  char *tmpPath;   /*եѥǥ쥯ȥѥ̾*/
  char *xmlDefVer; /*XMLΥǥեȥС*/
  char *xmlDefEnc; /*XMLΥǥեȥ󥳡ǥ*/
  char *xtDefVer;  /*XMLtableΥǥեȥС*/
  int    txtFlg;   /*XMLtableǤʤplain textǡȤե饰(mssSetOptionؿ*/
  int    allocDeb; /*ΰѿΥǥХåե饰*/
  struct mssAllocInf *allocInf;
  int    allocCnt;   /*{M,C,Re}allocΰݤ*/
  int    allocFreeCnt; /*{M,C,Re}alloc-FreeΰݤƤ(ƳƤкǸˤ0ˤʤϤ)*/
  int    writeHeaderFlg; /*إå˽ϤƤ飱ʤУ(mssWriteHeaderؿǥå)*/
  int    writeFooterFlg; /*եå˽ϤƤ飱ʤУ*/
  int    usedTempFileFlg;   /*եѤƤե饰*/
  char   sigDigitsForm[10]; /*ͭ(%.10gʤ)*/
};

/**
 * # STRUCT #
 * ưŪݤΥǥХåѾ
 */
struct mssAllocInf {
  int func;  /*0:free,1:calloc,2:malloc,3:realloc,4:reallocLim,5:strdup*/
  void *add; /*ɥ쥹*/
  int cnt;   /*AllocCnt*/
  char *msg; /*å*/
  int refNo; /*allocФfree,freeФallocֹ*/
};

/**
 * # STRUCT #
 * ʸConcatenateĤʸΰ빽¤
 */
struct mssStrings {
  char *str;    /*Ƭʸ*/
  int   cnt;    /*ʸ*/
};

/**
 * # STRUCT #
 * ʸꥹȤȤϿ빽¤
 * Ͽ줿nܤʸؤΥݥ󥿤ˤ륢ǽ
 */
struct mssStrList {
  char *str;     /*ʸꥹȤƬ*/
  int  *pointer; /*ʸŪ(Ƭʸ)*/
  int   cnt;     /*Ͽ줿ʸ*/
  int   chrCnt;  /*Ͽ줿ʸ*/
};

/**
 * # PROTOTYPE # 
 */
void 			mssSetSignalHandler();
void			mssInit(int argc, char **argv, struct mssComHelp *comHelp);
void			mssEnd(int status);
void 			mssShowStartMsg();
void 			mssShowEndMsg();
void 			mssShowErrMsg(char *msg, ...);
void 			mssShowMsg(char *msg, ...);
void *			mssCalloc(int size, char *errMsg);
void *			mssMalloc(int size, char *errMsg);
void *			mssRealloc(void *ptr, int size, char *errMsg);
void *			mssReallocLim(void *ptr,int size,int lim,char *errMsg);
char *			mssStrdup(char *s);
void			mssFree(void *add);
void			mssShowAllocInf(void);
struct mssStrings *	mssInitStrings();
void 			mssFreeStrings(struct mssStrings *s);
void 			mssCatStrings(struct mssStrings *s, char *str);
void			mssCatnStrings(struct mssStrings *s, char *str, int n);
struct mssStrList *	mssInitStrList();
void 			mssFreeStrList(struct mssStrList *s);
void 			mssPutStrList(struct mssStrList *s, char *str);
char *			mssGetStrList(struct mssStrList *s,int n);
char *                  mssCatTwoStrings(char *str1, char *str2);
char *			mssSkipStrBlock(char *str, char startChr, char endChr);
void			mssSwapInt(int *x, int *y);
void			mssSwapLng(long *x, long *y);
void			mssSwapDbl(double *x, double *y);
char **			mssTokByChr(char *string, char tok, int *cnt, int dup);
int			mssIsValidStr(char *str);
char *			mssItoA(int num);
char *			mssFtoA(double num);
time_t			mssStrToTime(char *str);
int			mssInitRand(int seed);
double			mssRand();
int			mssIRand(int from, int to);
double			mssNRand(double m, double s);

#endif /* _FP_H */

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/lib/include/musashi/mssBase.h <==
/**
 * # CHAPTER #
 * ============================================================================
 * MUSASHIѤŪʴؿѤΥإåե
 * ============================================================================
 */

#include <musashi/mssConfig.h>

#include <stdlib.h>
#include <time.h>

#ifndef __MSSBASE_H
#define __MSSBASE_H 1


/**
 * # DEFINE #
 * ｪλ
 */
#define mssExitSuccess EXIT_SUCCESS /*ｪλ*/

/**
 * # DEFINE #
 *ǥեȤΥ顼λֹ
 */
#define mssErrorNoDefault 1

/**
 * # DEFINE #
 * 
 */
#define mssRandMax 2147483647

/**
 * # STRUCT #
 * ޥɥإפη
 */
struct mssComHelp {
  char *name;      /*ޥ̾*/
  char *version;   /*С*/
  char *title;     /*ȥ*/
  char *summary;   /**/
  char *example;   /**/
  char *reference; /*ȥޥ*/
  char *author;    /**/
  char *bugReport; /*ХݡE-mail*/
  char *homepage;  /*ޥɤ˴ؤHP*/
};

/**
 * # STRUCT #
 * ưŪݤΥǥХåѾ
 */
struct mssAllocInf {
  int func;  /*0:free,1:calloc,2:malloc,3:realloc,4:reallocLim,5:strdup*/
  void *add; /*ɥ쥹*/
  int cnt;   /*AllocCnt*/
  int size;
  char msg[256]; /*å*/
  int refNo; /*allocФfree,freeФallocֹ*/
};


/**
 * # STRUCT #
 * MUSASHIѤ륰Хѿ¤(base.cˤ)
 */
struct mssGlobalVariables {
  struct mssComHelp *comHelp; /*ޥɥإ*/
  int    inCnt;    /*ǡϹԿ*/
  int    outCnt;   /*ǡϹԿ*/
  int    keyNo;    /*߽Υֹ*/
  int    keyCnt;   /*߽ΥιԿ*/
  int    keyLine;  /*߽ΥΤʤǤιֹ*/
                   /*嵭γƼϡAPIǤϰڹʤΤǡƥޥɤ
                     ץꤹ롣
                     inCnt,outCntϡޥɽλå(mssShowEndMsgؿ)
                     ΰȤƽϤ롣*/
  int    inFldCnt; /*ϥǡιܿ(cal_priorؿ)*/
  int    quiet;    /*åϤ򤷤ʤե饰(mssInit,setOptionؿ)*/
  int    argc;     /*ޥɥ饤(mssInitؿ)*/
  char **argv;     /*ޥɥ饤(mssInitؿ)*/
  char *tmpPath;   /*եѥǥ쥯ȥѥ̾*/
  char *xmlDefVer; /*XMLΥǥեȥС*/
  char *xmlDefEnc; /*XMLΥǥեȥ󥳡ǥ*/
  char *xtDefVer;  /*XMLtableΥǥեȥС*/
  int    txtFlg;   /*XMLtableǤʤplain textǡȤե饰(mssSetOptionؿ*/
  int    allocDeb; /*ΰѿΥǥХåե饰*/
  struct mssAllocInf allocInf[50000];
  int    allocCnt;   /*{M,C,Re}allocΰݤ*/
  int    allocFreeCnt; /*{M,C,Re}alloc-FreeΰݤƤ(ƳƤкǸˤ0ˤʤϤ)*/
  int    writeHeaderFlg; /*إå˽ϤƤ飱ʤУ(mssWriteHeaderؿǥå)*/
  int    writeFooterFlg; /*եå˽ϤƤ飱ʤУ*/
  int    usedTempFileFlg;   /*եѤƤե饰*/
  char   sigDigitsForm[10]; /*ͭ(%.10gʤ)*/
};

/**
 * # STRUCT #
 * ʸConcatenateĤʸΰ빽¤
 */
struct mssStrings {
  char *str;    /*Ƭʸ*/
  int   cnt;    /*ʸ*/
};

/**
 * # STRUCT #
 * ʸꥹȤȤϿ빽¤
 * Ͽ줿nܤʸؤΥݥ󥿤ˤ륢ǽ
 */
struct mssStrList {
  char *str;     /*ʸꥹȤƬ*/
  int  *pointer; /*ʸŪ(Ƭʸ)*/
  int   cnt;     /*Ͽ줿ʸ*/
  int   chrCnt;  /*Ͽ줿ʸ*/
};

/**
 * # PROTOTYPE # 
 */
void 			mssSetSignalHandler();
void			mssInit(int argc, char **argv, struct mssComHelp *comHelp);
void			mssEnd(int status);
void 			mssShowStartMsg();
void 			mssShowEndMsg();
void 			mssShowErrMsg(char *msg, ...);
void 			mssShowMsg(char *msg, ...);
void *			mssCalloc(int size, char *errMsg);
void *			mssMalloc(int size, char *errMsg);
void *			mssRealloc(void *ptr, int size, char *errMsg);
void *			mssReallocLim(void *ptr,int size,int lim,char *errMsg);
char *			mssStrdup(char *s);
void			mssFree(void *add);
void			mssShowAllocInf(void);
void			mssAddAllocLabel(char *msg);
struct mssStrings *	mssInitStrings();
void 			mssFreeStrings(struct mssStrings *s);
void 			mssCatStrings(struct mssStrings *s, char *str);
void			mssCatnStrings(struct mssStrings *s, char *str, int n);
struct mssStrList *	mssInitStrList();
void 			mssFreeStrList(struct mssStrList *s);
void 			mssPutStrList(struct mssStrList *s, char *str);
char *			mssGetStrList(struct mssStrList *s,int n);
char *                  mssCatTwoStrings(char *str1, char *str2);
char *			mssSkipStrBlock(char *str, char startChr, char endChr);
void			mssSwapInt(int *x, int *y);
void			mssSwapLng(long *x, long *y);
void			mssSwapDbl(double *x, double *y);
char **			mssTokByChr(char *string, char tok, int *cnt, int dup);
int			mssIsValidStr(char *str);
char *			mssItoA(int num);
char *			mssFtoA(double num);
time_t			mssStrToTime(char *str);
int			mssInitRand(int seed);
double			mssRand();
int			mssIRand(int from, int to);
double			mssNRand(double m, double s);
int			mssPRand(double m);
void			mssSort(char **data, int cnt, int flag);


#endif /* _FP_H */
